SpeechToTextService class
Constructors
- SpeechToTextService()
-
factory
Properties
- currentFieldId → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isListening → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
stopListening(
) → Future< void> -
toggleListening(
{required String fieldId, required TextEditingController controller, void onResult(String text)?, void onStatus(String status)?, void onError(String error)?}) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited